VantageExportArtifact class
An artifact contributed to a bug-bundle export.
Constructors
- VantageExportArtifact({required String filename, required Uint8List bytes, bool isText = false, VantageSensitivity sensitivity = VantageSensitivity.normal})
-
const
Properties
- bytes → Uint8List
-
Raw bytes of the artifact.
final
- filename → String
-
Name for the artifact inside the exported bundle. Must be non-empty and
must not contain path separators or
...final - hashCode → int
-
The hash code for this object.
no setterinherited
- isText → bool
-
Whether bytes are UTF-8 text. Text artifacts are run through the export
redactor by the host pipeline — a binary artifact cannot be, so producers
of binary blobs must redact before returning them.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensitivity → VantageSensitivity
-
Handling class for this artifact.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited